from ...utils.abbreviated_enum import AbbreviatedEnum


class SurveyDirection(AbbreviatedEnum):
    downstream = ("Downstream", "D")
    upstream = ("Upstream", "U")
